/*---[ savelog.h ]----------------------------------------------------
 * Copyright (C) 2000 Tomas Junnonen (majix@sci.fi)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Functions for saving the contents of the hit log to a disk file
 *--------------------------------------------------------------------*/

#ifndef _FIRESTARTER_SAVELOG
#define _FIRESTARTER_SAVELOG

#include <config.h>
#include <gnome.h>

void savelog_show_dialog (void);

#endif
